local L = AceLibrary("AceLocale-2.2"):new("SqueenixScope")
local modifier, bind, frame

BINDING_HEADER_SQUEENIX_SCOPE_BINDING_HEADER = L.bindingheader 
BINDING_NAME_SQUEENIX_SCOPE_BINDING_KEY = L.bindingkey

local mod = Squeenix:NewModule("Scope", "AceEvent-2.0")

function mod:OnInitialize()
	self.db = Squeenix:AcquireDBNamespace("Scope")
	Squeenix.Options.args[L.scopekey] = {
    type = "text", name = L.scopekeyname, desc = L.scopekeydesc,
    get = function() return mod.db.profile.key or "Shift" end,
    set = function(n) mod.db.profile.key = n mod:OnDisable() mod:OnEnable() end,
    validate = L.validate
	}
	Squeenix.Options.args[L.scopepoint] = {
    type = "range", name = L.scopepointname, desc = L.scopepointdesc,
    get = function() return mod.db.profile.point or 5 end,
    set = function(n) mod.db.profile.point = n end,
    min = 0, max = 5, step = 1
  }
	Squeenix.Options.args[L.scopedelay] = {
    type = "range", name = L.scopedelayname, desc = L.scopedelaydesc,
    get = function() return mod.db.profile.delay or 0 end,
    set = function(n) mod.db.profile.delay = n mod:OnDisable() mod:OnEnable() end,
    min = 0, max = 30, step = 1
  }
end

function mod:OnEnable()
  self.ScopeOff()
  if self.db.profile.key == L.None then return end
  Minimap:SetScript("OnEnter", self.ScopeOn)
  if (self.db.profile.delay or 0) > 0 then return end
  Minimap:SetScript("OnLeave", self.ScopeOff)
end

function mod:OnDisable()
  Minimap:SetScript("OnEnter", nil) Minimap:SetScript("OnLeave", nil)
end

function mod:Toggle()
  self["Scope"..(self.db.profile.zoom and "Off" or "On")](true)
end

function mod.ScopeOn(bind)
  modifier = getglobal("Is"..(mod.db.profile.key or "Shift").."KeyDown")
  if (modifier and modifier()) or bind == true then
    mod.db.profile.zoom = mod.db.profile.zoom or Minimap:GetZoom()
    Minimap:SetZoom(mod.db.profile.point or 5)
    if bind ~= true and (mod.db.profile.delay or 0) > 0 then
      mod:ScheduleEvent("ScopeDelay", mod.ScopeOff, mod.db.profile.delay)
    end if bind == true then mod.bind = true end
  end modifier = nil
end

function mod.ScopeOff(bind)
  if bind ~= true then
    frame = GetMouseFocus() and GetMouseFocus():GetName() or nil
    if frame and string.find(frame, "Cartographer") then frame = nil return
    elseif mod.bind then return end
  else mod.bind = nil end
  if mod.db.profile.zoom then
    Minimap:SetZoom(mod.db.profile.zoom) mod.db.profile.zoom = nil
  end
end
